this code is used for my learning, 
because other wheels are not enough or perfect  
author: nwkami.   
init.py should put in a path named as your package name,and "name = "example_pkg""in it
again I move the code py into the path where init in. and in init we write "from xxx import *"  
then this version is the first usable version
README文件中有中文的时候，setup需要有特殊的设置。  
这一版我加上了  
库函数的代码我没有改  
~~~~~~~~~~~~~~~~~~~~~  
更新：加上了get_location_by_name函数  
更新：加上了matrixlizing_function函数，  
不过主要是用来备份上次的projec1的东西，因为我要  
把两个代码合起来了，要先备份一下